Name:           voro++
Version:        0.4.6
Release:        9%{?dist}
Summary:        Library for 3D computations of the Voronoi tessellation

Group:          Applications/Engineering
License:        LBNL BSD
URL:            http://math.lbl.gov/voro++/
Source0:        http://math.lbl.gov/voro++/download/dir/%{name}-%{version}.tar.gz
Source1:        CMakeLists.txt

BuildRequires:  cmake

# Make base class destructors virtual
Patch0:         voro++_virtual-destructor.patch
# Fix manpage formatting
Patch1:         voro++_man.patch

%description
Voro++ is a software library for carrying out three-dimensional computations 
of the Voronoi tessellation. A distinguishing feature of the Voro++ library 
is that it carries out cell-based calculations, computing the Voronoi cell for 
each particle individually. It is particularly well-suited for applications 
that rely on cell-based statistics, where features of Voronoi cells (e.g. 
volume, centroid, number of faces) can be used to analyze a system of particles.


%package devel
Summary:        %{name} headers
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
Header files for %{name}.


%package doc
Summary:        %{name} documentation
BuildArch:      noarch

%description doc
Documentation for %{name}.


%prep
%setup -q -n %{name}-%{version}
%patch0 -p1
%patch1 -p1

cp -a %{SOURCE1} src


%build
pushd src
mkdir build
pushd build
%cmake ..
make %{?_smp_mflags}
popd
popd

%install
%make_install -C src/build
install -Dpm 0644 man/voro++.1 %{buildroot}%{_mandir}/man1/voro++.1

# Fix path in examples
find examples -name "*.cc" -exec sed -i 's/"voro++.hh"/<voro++\/voro++.hh>/g' '{}' \;
cp config.mk examples/
find examples -name "Makefile" -exec sed -i 's/..\/..\/config.mk/..\/config.mk/g' '{}' \;


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%doc LICENSE README NEWS
%{_bindir}/%{name}
%{_mandir}/man1/*
%{_libdir}/lib%{name}.so.*

%files devel
%{_includedir}/*
%{_libdir}/lib%{name}.so

%files doc
%doc LICENSE
%doc html/
%doc examples/
%doc scripts/


%changelog
* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.6-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 0.4.6-8
- Rebuilt for GCC 5 C++11 ABI change

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.6-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Jun 19 2014 Sandro Mani <manisandro@gmail.com> - 0.4.6-6
- Fix license
- doc subpackage
- Fix manpage formatting

* Thu Jun 19 2014 Sandro Mani <manisandro@gmail.com> - 0.4.6-5
- Merge libs subpackage into main package

* Thu Jun 19 2014 Sandro Mani <manisandro@gmail.com> - 0.4.6-4
- Add missing -libs requires for main package

* Thu Jun 19 2014 Sandro Mani <manisandro@gmail.com> - 0.4.6-3
- Build proper versioned shared libraries

* Sat Jun 14 2014 Sandro Mani <manisandro@gmail.com> - 0.4.6-2
- Spec cleanup
- Add voro++_virtual-destructor.patch

* Fri Feb 14 2014 Alexey Vasyukov <vasyukov@gmail.com> - 0.4.6-1
- Initial package for Fedora
